@@ -4,9 +4,9 @@ import typing as tp
 import re
 
 from ormlambda.sql.types import ASTERISK
-from ormlambda.errors import DuplicatedClauseNameError
+from ormlambda.common.errors import DuplicatedClauseNameError
 from .interface import IClauseInfo
-from ormlambda.common import GlobalChecker
+from ormlambda.common import GlobalChecker, DOT
 from ormlambda import util
 
 
@@ -46,6 +46,8 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
     def __init__(self, table: TableType[T], preserve_context: tp.Optional[bool] = ...): ...
     @tp.overload
     def __init__[TProp](self, table: TableType[T], dtype: tp.Optional[TProp] = ...): ...
+    @tp.overload
+    def __init__(self, table: TableType[T], literal: bool = ...): ...
 
     @tp.overload
     def __init__(self, dialect: Dialect, *args, **kwargs): ...
@@ -122,8 +124,10 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
     @property
     def alias_table(self) -> tp.Optional[str]:
         alias = self._alias_table
+
         return self._alias_resolver(alias)
 
+
     # TODOL [ ]: if we using this setter, we don't update the _context with the new value. Study if it's necessary
     @alias_table.setter
     def alias_table(self, value: str) -> str:
@@ -146,7 +150,7 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
             return self._dtype
 
         if self.is_column(self._column):
-            return self._column.dtype
+            return self._column.dtype.python_type
 
         if isinstance(self._column, type):
             return self._column
@@ -185,7 +189,8 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
         # When passing the Table itself without 'column'
         if self.table and not self._column:
             if not self._alias_table:
-                return self.table.__table_name__
+                return self.join_db_and_table(self.table)
+
             alias_table = self.alias_table
             return self.concat_alias_and_column(self.table.__table_name__, alias_table)
 
@@ -193,6 +198,20 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
             return self._get_all_columns(dialect)
         return self._join_table_and_column(self._column, dialect)
 
+    @classmethod
+    def join_db_and_table(cls, table: str| Table, table_name: tp.Optional[str] = None) -> str:
+        table_name = table.__table_name__ if (not table_name and hasattr(table,"__table_name__")) else table_name
+
+        db = table.__db_name__ if hasattr(table,"__db_name__") else None
+
+        wrapped_table = cls.wrapped_with_quotes(table_name)
+
+        if db:
+            wrapped_db = cls.wrapped_with_quotes(db)
+            return f"{wrapped_db}{DOT}{wrapped_table}"
+
+        return wrapped_table
+
     @util.preload_module("ormlambda.sql")
     def _join_table_and_column[TProp](self, column: ColumnType[TProp], dialect: Dialect) -> str:
         ColumnProxy = util.preloaded.sql_column.ColumnProxy
@@ -200,15 +219,17 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
         caster = dialect.caster()
 
         if self.alias_table:
-            table = self.wrapped_with_quotes(self.alias_table)
+            col = column.table if hasattr(column, "table") else column
+            table = self.join_db_and_table(col, self.alias_table)
         elif isinstance(column, ColumnProxy):
-            table = self.wrapped_with_quotes(column.get_table_chain())
+            table_name: str = column.get_table_chain()
+            table = self.join_db_and_table(column.table, table_name)
         else:
             table = self.table.__table_name__
 
         column: str = self._column_resolver(column)
 
-        table_column = f"{table}.{column}"
+        table_column = f"{table}{DOT}{column}"
 
         dtype = str if self.is_table(self.dtype) else self.dtype
         wrapped_column = caster.for_value(table_column, dtype).wildcard_to_select(table_column)
@@ -309,7 +330,7 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
 
     @util.preload_module("ormlambda.sql.clauses")
     @staticmethod
-    def join_clauses(clauses: list[ColumnProxy], chr: str = ",", *, dialect: Dialect, **kw) -> str:
+    def join_clauses(clauses: list[ColumnProxy], chr: str = " ", *, dialect: Dialect, **kw) -> str:
         IComparer = util.preloaded.sql_comparer.IComparer
 
         raise_alias_duplicated = False
@@ -345,7 +366,7 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
 
         if raise_alias_duplicated:
             raise DuplicatedClauseNameError(tuple(alias for alias, number in all_aliases.items() if number > 1))
-        return f"{chr} ".join(queries)
+        return f",{chr}".join(queries)
 
     @staticmethod
     def wrapped_with_quotes(
@@ -375,7 +396,7 @@ class ClauseInfo[T: Table](IClauseInfo[T]):
     def is_table(data: ColumnType | Table | ForeignKey) -> bool:
         Table = util.preloaded.sql_table.Table
         TableProxy = util.preloaded.sql_table.TableProxy
-        
+
         return isinstance(data, type) and issubclass(data, Table | TableProxy)
 
     @util.preload_module("ormlambda.sql")
