@@ -173,7 +173,7 @@ class IStatements[T: Table](Element):
     @overload
     def order[TValue](self, columns: Iterable[SelectCols[T, TValue]]) -> IStatements[T]: ...
     @overload
-    def order[TValue](self, columns: Iterable[SelectCols[T, TValue]], order_type: Iterable[OrderTypes]) -> IStatements[T]: ...
+    def order[TValue](self, columns: Iterable[SelectCols[T, TValue]], order_type: OrderTypes) -> IStatements[T]: ...
     @abstractmethod
     def order[TValue](self, columns, order_type=...) -> IStatements[T]: ...
 
@@ -209,6 +209,8 @@ class IStatements[T: Table](Element):
     # endregion
     # region select
     @overload
+    def select(self, selector: Optional[Callable[[T], tuple]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
+    @overload
     def select[T1](self, selector: Callable[[T], T1 | tuple[T1]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> tuple[T1, ...]: ...
     @overload
     def select[*T1](self, selector: Callable[[T], tuple[*T1]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> Tuple[*T1]: ...
@@ -217,12 +219,15 @@ class IStatements[T: Table](Element):
 
     # region deal with flavours
     @overload
+    def select[TProp](self, selector: Callable[[T], TProp] = ..., *, flavour: Type[tuple], **kwargs) -> tuple[TProp, ...]: ...
+    @overload
     def select[*TRes](self, selector: Callable[[T], tuple[*TRes]] = ..., *, flavour: Type[tuple], **kwargs) -> tuple[tuple[*TRes]]: ...
     @overload
     def select[TFlavour](self, selector: Callable[[T], tuple] = ..., *, flavour: Type[TFlavour], **kwargs) -> tuple[TFlavour, ...]: ...
 
-    # endregion
+    # FIXME [ ]: select when passing only one element out of the tuple no return tuple[tuple[T,...]] and it should return tuple[T]
 
+    # endregion
     @abstractmethod
     def select(
         self,
@@ -232,11 +237,14 @@ class IStatements[T: Table](Element):
         by=...,
         alias=...,
         avoid_duplicates=...,
+        only_query=...,
     ): ...
 
     # endregion
     # region select_one
     @overload
+    def select_one(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
+    @overload
     def select_one(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> T: ...
     @overload
     def select_one[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> tuple[*TRes]: ...
@@ -258,23 +266,26 @@ class IStatements[T: Table](Element):
         alias=...,
         flavour=...,
         avoid_duplicates=...,
+        only_query=...,
     ): ...
 
     # endregion
 
     # region first
     @overload
-    def first(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> T: ...
+    def first(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
     @overload
-    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> tuple[*TRes]: ...
+    def first(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ..., only_query: bool = ...) -> T: ...
     @overload
-    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[tuple], avoid_duplicates: bool = ...) -> tuple[*TRes]: ...
+    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ..., only_query: bool = ...) -> tuple[*TRes]: ...
     @overload
-    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[list], avoid_duplicates: bool = ...) -> tuple[*TRes]: ...
+    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[tuple], avoid_duplicates: bool = ..., only_query: bool = ...) -> tuple[*TRes]: ...
     @overload
-    def first[TFlavour](self, selector: Callable[[T], Any], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[TFlavour], avoid_duplicates: bool = ...) -> TFlavour: ...
+    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[list], avoid_duplicates: bool = ..., only_query: bool = ...) -> tuple[*TRes]: ...
     @overload
-    def first(self, selector: Callable[[T], tuple], *, by: JoinType = ..., flavour: Type[dict], alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> dict[str, Any]: ...
+    def first[TFlavour](self, selector: Callable[[T], Any], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[TFlavour], avoid_duplicates: bool = ..., only_query: bool = ...) -> TFlavour: ...
+    @overload
+    def first(self, selector: Callable[[T], tuple], *, by: JoinType = ..., flavour: Type[dict], alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ..., only_query: bool = ...) -> dict[str, Any]: ...
 
     @abstractmethod
     def first(
@@ -285,6 +296,7 @@ class IStatements[T: Table](Element):
         alias=...,
         flavour=...,
         avoid_duplicates=...,
+        only_query=...,
     ): ...
 
     # endregion
